@@ -1,6 +1,6 @@
-from bergen.types.model import  ArnheimModelManager
+from bergen.types.manager import  ModelManager
 
-class RepresentationManager(ArnheimModelManager):
+class RepresentationManager(ModelManager):
 
     def from_xarray(self, array, compute=True, **kwargs):
         instance = self.create(**kwargs)
