@@ -1,9 +1,14 @@
-from grunnlag.gql import CREATE_REPRESENTATION, GET_REPRESENTATION, UPDATE_REPRESENTATION, FILTER_REPRESENTATION
+from grunnlag.gql.sample import CREATE_SAMPLE, FILTER_SAMPLE, GET_SAMPLE
+from grunnlag.gql.representation import CREATE_REPRESENTATION, GET_REPRESENTATION, UPDATE_REPRESENTATION, FILTER_REPRESENTATION
 from grunnlag.managers import RepresentationManager
-from typing import List, Optional
-from bergen.schema import ArnheimModel, User
+from typing import ForwardRef, List, Optional
+from bergen.types.model import ArnheimModel
+from bergen.schema import User
 from grunnlag.extenders import Array, RepresentationPrettifier
 
+Representation = ForwardRef("Representation")
+
+
 class Representation(RepresentationPrettifier, Array, ArnheimModel):
     id: Optional[int]
     name: Optional[str]
@@ -11,10 +16,9 @@ class Representation(RepresentationPrettifier, Array, ArnheimModel):
     store: Optional[str]
     shape: Optional[List[int]]
     image: Optional[str]
-    creator: Optional[User]
     unique: Optional[str]
 
-    objects = RepresentationManager
+    objects = RepresentationManager()
 
     class Meta:
         identifier = "representation"
@@ -24,5 +28,20 @@ class Representation(RepresentationPrettifier, Array, ArnheimModel):
         filter = FILTER_REPRESENTATION
 
 
+class Sample(ArnheimModel):
+    id: Optional[int]
+    representations: Optional[List[Representation]]
+    creator: Optional[User]
+
+    class Meta:
+        identifier = "sample"
+        get = GET_SAMPLE
+        filter = FILTER_SAMPLE
+        create = CREATE_SAMPLE
 
 
+
+
+
+Representation.update_forward_refs()
+
